summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--kontact_plugin/basket_plugin.h2
-rw-r--r--src/aboutdata.cpp4
-rw-r--r--src/aboutdata.h2
-rw-r--r--src/basket_part.cpp2
-rw-r--r--src/basket_part.h2
-rw-r--r--src/global.h4
-rw-r--r--src/likeback.cpp6
-rw-r--r--src/likeback.h10
-rw-r--r--src/likeback_private.h2
9 files changed, 17 insertions, 17 deletions
diff --git a/kontact_plugin/basket_plugin.h b/kontact_plugin/basket_plugin.h
index 29f7a7b..a8cbf72 100644
--- a/kontact_plugin/basket_plugin.h
+++ b/kontact_plugin/basket_plugin.h
@@ -27,7 +27,7 @@
#include "uniqueapphandler.h"
#include "basketdcopiface_stub.h"
-class KAboutData;
+class TDEAboutData;
class BasketUniqueAppHandler : public Kontact::UniqueAppHandler
{
diff --git a/src/aboutdata.cpp b/src/aboutdata.cpp
index fa70b6f..b5e8cfd 100644
--- a/src/aboutdata.cpp
+++ b/src/aboutdata.cpp
@@ -31,8 +31,8 @@ static const char description[] = I18N_NOOP(
// Or how to make order of disorganized toughts.
AboutData::AboutData()
- : KAboutData( "basket", I18N_NOOP("BasKet Note Pads"),
- VERSION, description, KAboutData::License_GPL_V2,
+ : TDEAboutData( "basket", I18N_NOOP("BasKet Note Pads"),
+ VERSION, description, TDEAboutData::License_GPL_V2,
"(c) 2003-2007, S\303\251bastien Lao\303\273t", 0,
"http://basket.kde.org/",
"basket-devel@lists.sourceforge.net" )
diff --git a/src/aboutdata.h b/src/aboutdata.h
index f8cfea4..6130c07 100644
--- a/src/aboutdata.h
+++ b/src/aboutdata.h
@@ -26,7 +26,7 @@
@author Sébastien Laoût <slaout@linux62.org>
*/
-class AboutData : public KAboutData
+class AboutData : public TDEAboutData
{
public:
AboutData();
diff --git a/src/basket_part.cpp b/src/basket_part.cpp
index ebfefa6..3ef759f 100644
--- a/src/basket_part.cpp
+++ b/src/basket_part.cpp
@@ -89,7 +89,7 @@ bool BasketPart::saveFile()
return false;
}
-KAboutData *BasketPart::createAboutData()
+TDEAboutData *BasketPart::createAboutData()
{
return new AboutData();
}
diff --git a/src/basket_part.h b/src/basket_part.h
index 068e659..719c604 100644
--- a/src/basket_part.h
+++ b/src/basket_part.h
@@ -66,7 +66,7 @@ public:
*/
virtual void setModified(bool modified);
- static KAboutData *createAboutData();
+ static TDEAboutData *createAboutData();
signals:
void showPart();
diff --git a/src/global.h b/src/global.h
index dcfc93e..7c4af68 100644
--- a/src/global.h
+++ b/src/global.h
@@ -31,7 +31,7 @@ class SystemTray;
class BNPView;
class KGlobalAccel;
class KMainWindow;
-class KAboutData;
+class TDEAboutData;
/** Handle all global variables of the application.
* This file only declare classes : developer should include
@@ -65,7 +65,7 @@ class Global
static TQString openNoteIcon(); /// << @return the icon used for the "Open" action on notes.
static KMainWindow* mainWindow();
static KConfig* config();
- static KAboutData* about() { return &basketAbout; };
+ static TDEAboutData* about() { return &basketAbout; };
};
#endif // GLOBAL_H
diff --git a/src/likeback_private.h b/src/likeback_private.h
index f4fe03a..970bc0d 100644
--- a/src/likeback_private.h
+++ b/src/likeback_private.h
@@ -39,7 +39,7 @@ class LikeBackPrivate
~LikeBackPrivate();
LikeBackBar *bar;
KConfig *config;
- const KAboutData *aboutData;
+ const TDEAboutData *aboutData;
LikeBack::Button buttons;
TQString hostName;
TQString remotePath;
diff --git a/src/likeback.cpp b/src/likeback.cpp
index caeea1a..33161fc 100644
--- a/src/likeback.cpp
+++ b/src/likeback.cpp
@@ -208,7 +208,7 @@ LikeBackPrivate::~LikeBackPrivate()
/********** class LikeBack: **********/
/*************************************/
-LikeBack::LikeBack(Button buttons, bool showBarByDefault, KConfig *config, const KAboutData *aboutData)
+LikeBack::LikeBack(Button buttons, bool showBarByDefault, KConfig *config, const TDEAboutData *aboutData)
: TQObject()
{
// Initialize properties (1/2):
@@ -364,7 +364,7 @@ LikeBack::Button LikeBack::buttons()
return d->buttons;
}
-const KAboutData* LikeBack::aboutData()
+const TDEAboutData* LikeBack::aboutData()
{
return d->aboutData;
}
@@ -566,7 +566,7 @@ void LikeBack::askEmailAddress()
setEmailAddress(email);
}
// FIXME: Should be moved to KAboutData? Cigogne will also need it.
bool LikeBack::isDevelopmentVersion(const TQString &version)
{
return version.find("alpha", /*index=*/0, /*caseSensitive=*/false) != -1 ||
@@ -566,7 +566,7 @@ void LikeBack::askEmailAddress()
setEmailAddress(email);
}
-// FIXME: Should be moved to KAboutData? Cigogne will also need it.
+// FIXME: Should be moved to TDEAboutData? Cigogne will also need it.
bool LikeBack::isDevelopmentVersion(const TQString &version)
{
diff --git a/src/likeback.h b/src/likeback.h
index fbe42ff..1f1b684 100644
--- a/src/likeback.h
+++ b/src/likeback.h
@@ -24,7 +24,7 @@
#include <tqobject.h>
class KConfig;
-class KAboutData;
+class TDEAboutData;
class KAction;
class KActionCollection;
@@ -119,12 +119,12 @@ class LikeBack : public TQObject
* This allow you to disable the button-bar once the version is stable enought to be released as final.
* @param config Set the configuration file where to store the user email address and if the button-bar should be shown.
* By default (null), the TDEApplication configuration object is used.
* @param aboutData Set the KAboutData instance used to get the application name and version. By default (null), the TDEApplication about data object is used.
* The application name is only used in the first-use information message.
* The version is used to store the button-bar visibility per version (can be shown in a development version but not in a final one...)
* and to send with the comment, so you can filter per version and know if a comment refers the latest version of the application or not.
*/
- LikeBack(Button buttons = DefaultButtons, bool showBarByDefault = false, KConfig *config = 0, const KAboutData *aboutData = 0);
+ LikeBack(Button buttons = DefaultButtons, bool showBarByDefault = false, KConfig *config = 0, const TDEAboutData *aboutData = 0);
/**
* Destructor.
@@ -324,10 +324,10 @@ class LikeBack : public TQObject
void setUserWantsToShowBar(bool showBar);
/**
* @Returns A pointer to the KAboutData used to determin the application name and version.
* @See The LikeBack constructor for more information.
*/
- const KAboutData *aboutData();
+ const TDEAboutData *aboutData();
/**
* @Returns A pointer to the KConfig used to store user configuration (email address, if the button-bar should be shown).
@@ -119,12 +119,12 @@ class LikeBack : public TQObject
* @param config Set the configuration file where to store the user email address and if the button-bar should be shown.
* By default (null), the TDEApplication configuration object is used.
- * @param aboutData Set the KAboutData instance used to get the application name and version. By default (null), the TDEApplication about data object is used.
+ * @param aboutData Set the TDEAboutData instance used to get the application name and version. By default (null), the TDEApplication about data object is used.
* The application name is only used in the first-use information message.
* The version is used to store the button-bar visibility per version (can be shown in a development version but not in a final one...)
@@ -324,10 +324,10 @@ class LikeBack : public TQObject
void setUserWantsToShowBar(bool showBar);
/**
- * @Returns A pointer to the KAboutData used to determin the application name and version.
+ * @Returns A pointer to the TDEAboutData used to determin the application name and version.
* @See The LikeBack constructor for more information.
*/